@@ -4,10 +4,10 @@ ARENA-py
 Draw objects and run programs in the ARENA using Python!
 """
 
-__version__     = "0.1.15"
+__version__     = "0.1.20"
 __author__      = "CONIX Research Center"
 
 __license__     = "BSD 3-Clause"
 __maintainer__  = "WiSE Lab, Carnegie Mellon University"
 
-from .arena import *
+from .scene import *
