@@ -9,6 +9,8 @@ class Object(BaseObject):
     Object class. Defines a generic object in the ARENA.
     """
 
+    type = "object"
+    object_type = "entity"
     all_objects = {} # dict of all objects created so far
 
     def __init__(self, evt_handler=None, update_handler=None, **kwargs):
@@ -39,10 +41,12 @@ class Object(BaseObject):
 
         # default "object_type" to entity
         if "object_type" not in kwargs:
-            kwargs["object_type"] = "entity"
+            kwargs["object_type"] = Object.object_type
 
         if "color" in kwargs:
-            print("[DEPRECATED]", "Color must now be specified in material=Material(color=Color(...))!")
+            if kwargs["object_type"] != "text" and kwargs["object_type"] != "thickline":
+                print("[DEPRECATED]",
+                    "Color must be specified in material=Material(color=Color(...))! (Does not hold for Text and Thicklines)")
 
         # print warning if object is being created with the same id as an existing object
         if Object.exists(object_id):
@@ -54,7 +58,7 @@ class Object(BaseObject):
         data = Data(**data)
         super().__init__(
                 object_id=object_id,
-                type="object",
+                type=Object.type,
                 persist=persist,
                 data=data
             )
@@ -104,6 +108,10 @@ class Object(BaseObject):
     def clear_animations(self):
         self.animations = []
 
+    @property
+    def clickable(self):
+        return "click_listener" in self.data or "clickable" in self.data
+
     def json_preprocess(self, **kwargs):
         # kwargs are for additional param to add to json, like "action":"create"
         json_payload = { k:v for k,v in vars(self).items() if k != "evt_handler" and \
